==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/CognitoIdp/UserPoolDescriptionType.pm <==
package Paws::CognitoIdp::UserPoolDescriptionType;
  use Moose;
  has CreationDate => (is => 'ro', isa => 'Str');
  has Id => (is => 'ro', isa => 'Str');
  has LambdaConfig => (is => 'ro', isa => 'Paws::CognitoIdp::LambdaConfigType');
  has LastModifiedDate => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has Status => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::UserPoolDescriptionType

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CognitoIdp::UserPoolDescriptionType object:

  $service_obj->Method(Att1 => { CreationDate => $value, ..., Status => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CognitoIdp::UserPoolDescriptionType object:

  $result = $service_obj->Method(...);
  $result->Att1->CreationDate

=head1 DESCRIPTION

A user pool description.

=head1 ATTRIBUTES


=head2 CreationDate => Str

  The creation date in a user pool description.


=head2 Id => Str

  The ID in a user pool description.


=head2 LambdaConfig => L<Paws::CognitoIdp::LambdaConfigType>

  The AWS Lambda configuration information in a user pool description.


=head2 LastModifiedDate => Str

  The last modified date in a user pool description.


=head2 Name => Str

  The name in a user pool description.


=head2 Status => Str

  The user pool status in a user pool description.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/CognitoIdp/UserPoolDescriptionType.pm <==
package Paws::CognitoIdp::UserPoolDescriptionType;
  use Moose;
  has CreationDate => (is => 'ro', isa => 'Str');
  has Id => (is => 'ro', isa => 'Str');
  has LambdaConfig => (is => 'ro', isa => 'Paws::CognitoIdp::LambdaConfigType');
  has LastModifiedDate => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has Status => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::UserPoolDescriptionType

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CognitoIdp::UserPoolDescriptionType object:

  $service_obj->Method(Att1 => { CreationDate => $value, ..., Status => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CognitoIdp::UserPoolDescriptionType object:

  $result = $service_obj->Method(...);
  $result->Att1->CreationDate

=head1 DESCRIPTION

A user pool description.

=head1 ATTRIBUTES


=head2 CreationDate => Str

  The date the user pool description was created.


=head2 Id => Str

  The ID in a user pool description.


=head2 LambdaConfig => L<Paws::CognitoIdp::LambdaConfigType>

  The AWS Lambda configuration information in a user pool description.


=head2 LastModifiedDate => Str

  The date the user pool description was last modified.


=head2 Name => Str

  The name in a user pool description.


=head2 Status => Str

  The user pool status in a user pool description.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
